@@ -11,6 +11,7 @@
 #' @param name name, or key of the value
 #' @param value any R object
 #' @param x a \code{'fastmap2'} object
+#' @param recursive whether to recursively apply \code{\link[base]{as.list}}
 #' @param ... passed to other methods
 #' @return A list of \code{'fastmap2'} instance
 #' @examples
@@ -178,6 +179,15 @@ update_fastmap2 <- function(from, to, override = TRUE){
 
 #' @rdname fastmap2
 #' @export
-as.list.fastmap2 <- function(x, ...){
-  .subset2(x, 'as_list')(...)
+as.list.fastmap2 <- function(x, recursive = FALSE, ...){
+  re <- .subset2(x, 'as_list')(...)
+  if( recursive ){
+    for(i in seq_along(re)){
+      item <- re[[i]]
+      if(inherits(item, "fastmap2")){
+        re[[i]] <- as.list(item, recursive = recursive, ...)
+      }
+    }
+  }
+  re
 }
